BOOL

Struct BOOL 

#[repr(transparent)]
pub struct BOOL(pub i32);
A 32-bit value representing boolean values and returned by some functions to indicate success or failure.

Tuple Fields

0: i32

Implementations

Source

impl BOOL

pub fn as_bool(self) -> bool

Converts the BOOL to a bool value.

pub fn ok(self) -> Result<(), Error>

Converts the BOOL to Result<()>.

pub fn unwrap(self)

Asserts that self is a success code.

pub fn expect(self, msg: &str)

Asserts that self is a success code using the given panic message.