Struct WIN32_ERROR
#[repr(transparent)]pub struct WIN32_ERROR(pub u32);Expand description
An error or status code value returned by some operating system functions.
Tuple Fields
0: u32Implementations
Sourceimpl WIN32_ERROR
impl WIN32_ERROR
Sourcepub const fn to_hresult(self) -> HRESULT
pub const fn to_hresult(self) -> HRESULT
Maps a Win32 error code to an HRESULT value.
Sourcepub fn from_error(error: &Error) -> Option<WIN32_ERROR>
pub fn from_error(error: &Error) -> Option<WIN32_ERROR>
Returns the Win32 error contained in error, if it represents one.
Sourcepub fn ok(self) -> Result<(), Error>
pub fn ok(self) -> Result<(), Error>
Converts the error to a Result, treating a successful code as Ok.
Sourcepub fn from_thread() -> WIN32_ERROR
pub fn from_thread() -> WIN32_ERROR
Creates a new WIN32_ERROR from the Win32 error code returned by GetLastError().